import { Component, NgModule, EventEmitter, Input, Output, Directive, HostListener, InjectionToken, Injectable, Inject } from '@angular/core';
import { CommonModule } from '@angular/common';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { IonicModule } from '@ionic/angular';
import { Subject, of, Observable } from 'rxjs';
import { debounceTime } from 'rxjs/operators';
import { __awaiter } from 'tslib';
import { HttpClient } from '@angular/common/http';
import { AppVersion } from '@ionic-native/app-version/ngx';
import { Device } from '@ionic-native/device/ngx';
import { HTTP } from '@ionic-native/http/ngx';
import { Media } from '@ionic-native/media/ngx';
import { NativeStorage } from '@ionic-native/native-storage/ngx';
import { StatusBar } from '@ionic-native/status-bar/ngx';
import { NavigationBar } from '@ionic-native/navigation-bar/ngx';
import { Admob } from '@ionic-native/admob/ngx';
import { AndroidFullScreen } from '@ionic-native/android-full-screen/ngx';
import { NativeAudio } from '@ionic-native/native-audio/ngx';
import { Deeplinks } from '@ionic-native/deeplinks/ngx';

class CentralizerComponent {
}
CentralizerComponent.decorators = [
    { type: Component, args: [{
                selector: 'centralizer, [centralizer]',
                template: "<div class=\"centering-container\">\n  <div class=\"centered-container\">\n    <ng-content></ng-content>\n  </div>\n</div>",
                styles: [""]
            },] }
];

class CentralizerModule {
}
CentralizerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    CentralizerComponent
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    CentralizerComponent
                ]
            },] }
];

class DebounceButtonComponent {
    constructor() {
        this.debounceClick = new EventEmitter();
        this.animationState = 'wait';
    }
    animateButton() {
        if (this.animationTimeout)
            clearTimeout(this.animationTimeout);
        this.animationState = 'pressed';
        this.animationTimeout = setTimeout(() => {
            this.animationState = 'wait';
        }, 200);
    }
    onDebounceClick(event) {
        this.debounceClick.emit(event);
    }
}
DebounceButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'debounce-button',
                template: "<ion-button debounceClick [fill]=\"fill\" [disabled]=\"disabled\" [shape]=\"shape\" [color]=\"color\" [ngClass]=\"cssClass\" [@buttonState]=\"animationState\" (click)=\"animateButton()\"\n  [debounceTime]=\"debounce\" (debounceClick)=\"onDebounceClick($event)\">\n  <ng-content></ng-content>\n</ion-button>",
                animations: [
                    trigger('buttonState', [
                        state('wait', style({
                            transform: 'scale(1)'
                        })),
                        state('pressed', style({
                            transform: 'scale(1.1)'
                        })),
                        transition('wait => pressed', animate('150ms ease-in')),
                        transition('pressed => wait', animate('150ms ease-out'))
                    ])
                ],
                styles: ["ion-button{--padding-end:var(--button-padding-end,0)!important;--padding-start:var(--button-padding-start,0)!important;--ripple-color:transparent!important;margin:var(--margin-top,0) var(--margin-right,0) var(--margin-bottom,0) var(--margin-left,0)!important;min-width:var(--min-width)!important;width:var(--width)!important}"]
            },] }
];
DebounceButtonComponent.ctorParameters = () => [];
DebounceButtonComponent.propDecorators = {
    cssClass: [{ type: Input }],
    fill: [{ type: Input }],
    disabled: [{ type: Input }],
    shape: [{ type: Input }],
    color: [{ type: Input }],
    debounce: [{ type: Input }],
    debounceClick: [{ type: Output }]
};

class DebounceClickDirective {
    constructor() {
        this.debounceTime = 500;
        this.debounceClick = new EventEmitter();
        this.clicks = new Subject();
    }
    ngOnInit() {
        this.subscription = this.clicks.pipe(debounceTime(this.debounceTime))
            .subscribe(event => this.debounceClick.emit(event));
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
    clickEvent(event) {
        event.preventDefault();
        event.stopPropagation();
        this.clicks.next(event);
    }
}
DebounceClickDirective.decorators = [
    { type: Directive, args: [{
                selector: '[debounceClick]'
            },] }
];
DebounceClickDirective.ctorParameters = () => [];
DebounceClickDirective.propDecorators = {
    debounceTime: [{ type: Input }],
    debounceClick: [{ type: Output }],
    clickEvent: [{ type: HostListener, args: ["click", ["$event"],] }]
};

class DebounceButtonModule {
}
DebounceButtonModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    DebounceButtonComponent, DebounceClickDirective
                ],
                imports: [
                    CommonModule,
                    IonicModule
                ],
                exports: [
                    DebounceButtonComponent
                ]
            },] }
];

class SpinnerComponent {
}
SpinnerComponent.decorators = [
    { type: Component, args: [{
                selector: 'spinner',
                template: "<div #ref><ng-content></ng-content></div>\n\n<ng-container *ngIf=\"ref.childNodes.length == 0\">\n  <ion-content *ngIf=\"withContainer; else withoutContainer\">\n    <centralizer>\n      <div class=\"rotating-square\" *ngIf=\"name === 'rotatingSquare'\"></div>\n      <div class=\"chasing-dot\" *ngIf=\"name === 'chasingDot'\">\n        <div class=\"chasing-dot__dot\"></div>\n        <div class=\"chasing-dot__dot\"></div>\n        <div class=\"chasing-dot__dot\"></div>\n        <div class=\"chasing-dot__dot\"></div>\n        <div class=\"chasing-dot__dot\"></div>\n        <div class=\"chasing-dot__dot\"></div>\n      </div>\n      <div class=\"double-bouncing-dot\" *ngIf=\"name === 'doubleBouncingDot'\">\n        <div class=\"double-bouncing-dot__dot1\"></div>\n        <div class=\"double-bouncing-dot__dot2\"></div>\n      </div>\n      <div class=\"stretching-bars\" *ngIf=\"name === 'stretchingBars'\">\n        <div class=\"stretching-bars__rect1\"></div>\n        <div class=\"stretching-bars__rect2\"></div>\n        <div class=\"stretching-bars__rect3\"></div>\n        <div class=\"stretching-bars__rect4\"></div>\n        <div class=\"stretching-bars__rect5\"></div>\n      </div>\n      <div class=\"chasing-squares\" *ngIf=\"name === 'chasingSquares'\">\n        <div class=\"chasing-squares__square1\"></div>\n        <div class=\"chasing-squares__square2\"></div>\n      </div>\n      <div class=\"scaling-dot\" *ngIf=\"name === 'scalingDot'\"></div>\n      <div class=\"double-rotating-dot\" *ngIf=\"name === 'doubleRotatingDot'\">\n        <div class=\"double-rotating-dot__dot1\"></div>\n        <div class=\"double-rotating-dot__dot2\"></div>\n      </div>\n      <div class=\"three-bouncing-dot\" *ngIf=\"name === 'threeBouncingDots'\">\n        <div class=\"three-bouncing-dot__dot1\"></div>\n        <div class=\"three-bouncing-dot__dot2\"></div>\n        <div class=\"three-bouncing-dot__dot3\"></div>\n      </div>\n      <div class=\"rotating-dot-circle\" *ngIf=\"name === 'rotatingDotCircle'\">\n        <div class=\"rotating-dot-circle__dot1\"></div>\n        <div class=\"rotating-dot-circle__dot2\"></div>\n        <div class=\"rotating-dot-circle__dot3\"></div>\n        <div class=\"rotating-dot-circle__dot4\"></div>\n        <div class=\"rotating-dot-circle__dot5\"></div>\n        <div class=\"rotating-dot-circle__dot6\"></div>\n        <div class=\"rotating-dot-circle__dot7\"></div>\n        <div class=\"rotating-dot-circle__dot8\"></div>\n        <div class=\"rotating-dot-circle__dot9\"></div>\n        <div class=\"rotating-dot-circle__dot10\"></div>\n        <div class=\"rotating-dot-circle__dot11\"></div>\n        <div class=\"rotating-dot-circle__dot12\"></div>\n      </div>\n      <div class=\"fading-square\" *ngIf=\"name === 'fadingSquare'\">\n        <div class=\"fading-square__square1\"></div>\n        <div class=\"fading-square__square2\"></div>\n        <div class=\"fading-square__square3\"></div>\n        <div class=\"fading-square__square4\"></div>\n        <div class=\"fading-square__square5\"></div>\n        <div class=\"fading-square__square6\"></div>\n        <div class=\"fading-square__square7\"></div>\n        <div class=\"fading-square__square8\"></div>\n        <div class=\"fading-square__square9\"></div>\n      </div>\n      <div class=\"simple-circle\" *ngIf=\"name === 'simpleSpinner'\">\n        <div class=\"simple-circle__circle1\"></div>\n        <div class=\"simple-circle__circle2\"></div>\n        <div class=\"simple-circle__circle3\"></div>\n        <div class=\"simple-circle__circle4\"></div>\n        <div class=\"simple-circle__circle5\"></div>\n        <div class=\"simple-circle__circle6\"></div>\n        <div class=\"simple-circle__circle7\"></div>\n        <div class=\"simple-circle__circle8\"></div>\n        <div class=\"simple-circle__circle9\"></div>\n        <div class=\"simple-circle__circle10\"></div>\n        <div class=\"simple-circle__circle11\"></div>\n        <div class=\"simple-circle__circle12\"></div>\n      </div>\n      <div class=\"folding-square\" *ngIf=\"name === 'foldingSquare'\">\n        <div class=\"folding-square__square1\"></div>\n        <div class=\"folding-square__square2\"></div>\n        <div class=\"folding-square__square4\"></div>\n        <div class=\"folding-square__square3\"></div>\n      </div>\n    </centralizer>\n  </ion-content>\n  <ng-template #withoutContainer>\n    <div class=\"rotating-square\" *ngIf=\"name === 'rotatingSquare'\"></div>\n    <div class=\"chasing-dot\" *ngIf=\"name === 'chasingDot'\">\n      <div class=\"chasing-dot__dot\"></div>\n      <div class=\"chasing-dot__dot\"></div>\n      <div class=\"chasing-dot__dot\"></div>\n      <div class=\"chasing-dot__dot\"></div>\n      <div class=\"chasing-dot__dot\"></div>\n      <div class=\"chasing-dot__dot\"></div>\n    </div>\n    <div class=\"double-bouncing-dot\" *ngIf=\"name === 'doubleBouncingDot'\">\n      <div class=\"double-bouncing-dot__dot1\"></div>\n      <div class=\"double-bouncing-dot__dot2\"></div>\n    </div>\n    <div class=\"stretching-bars\" *ngIf=\"name === 'stretchingBars'\">\n      <div class=\"stretching-bars__rect1\"></div>\n      <div class=\"stretching-bars__rect2\"></div>\n      <div class=\"stretching-bars__rect3\"></div>\n      <div class=\"stretching-bars__rect4\"></div>\n      <div class=\"stretching-bars__rect5\"></div>\n    </div>\n    <div class=\"chasing-squares\" *ngIf=\"name === 'chasingSquares'\">\n      <div class=\"chasing-squares__square1\"></div>\n      <div class=\"chasing-squares__square2\"></div>\n    </div>\n    <div class=\"scaling-dot\" *ngIf=\"name === 'scalingDot'\"></div>\n    <div class=\"double-rotating-dot\" *ngIf=\"name === 'doubleRotatingDot'\">\n      <div class=\"double-rotating-dot__dot1\"></div>\n      <div class=\"double-rotating-dot__dot2\"></div>\n    </div>\n    <div class=\"three-bouncing-dot\" *ngIf=\"name === 'threeBouncingDots'\">\n      <div class=\"three-bouncing-dot__dot1\"></div>\n      <div class=\"three-bouncing-dot__dot2\"></div>\n      <div class=\"three-bouncing-dot__dot3\"></div>\n    </div>\n    <div class=\"rotating-dot-circle\" *ngIf=\"name === 'rotatingDotCircle'\">\n      <div class=\"rotating-dot-circle__dot1\"></div>\n      <div class=\"rotating-dot-circle__dot2\"></div>\n      <div class=\"rotating-dot-circle__dot3\"></div>\n      <div class=\"rotating-dot-circle__dot4\"></div>\n      <div class=\"rotating-dot-circle__dot5\"></div>\n      <div class=\"rotating-dot-circle__dot6\"></div>\n      <div class=\"rotating-dot-circle__dot7\"></div>\n      <div class=\"rotating-dot-circle__dot8\"></div>\n      <div class=\"rotating-dot-circle__dot9\"></div>\n      <div class=\"rotating-dot-circle__dot10\"></div>\n      <div class=\"rotating-dot-circle__dot11\"></div>\n      <div class=\"rotating-dot-circle__dot12\"></div>\n    </div>\n    <div class=\"fading-square\" *ngIf=\"name === 'fadingSquare'\">\n      <div class=\"fading-square__square1\"></div>\n      <div class=\"fading-square__square2\"></div>\n      <div class=\"fading-square__square3\"></div>\n      <div class=\"fading-square__square4\"></div>\n      <div class=\"fading-square__square5\"></div>\n      <div class=\"fading-square__square6\"></div>\n      <div class=\"fading-square__square7\"></div>\n      <div class=\"fading-square__square8\"></div>\n      <div class=\"fading-square__square9\"></div>\n    </div>\n    <div class=\"simple-circle\" *ngIf=\"name === 'simpleSpinner'\">\n      <div class=\"simple-circle__circle1\"></div>\n      <div class=\"simple-circle__circle2\"></div>\n      <div class=\"simple-circle__circle3\"></div>\n      <div class=\"simple-circle__circle4\"></div>\n      <div class=\"simple-circle__circle5\"></div>\n      <div class=\"simple-circle__circle6\"></div>\n      <div class=\"simple-circle__circle7\"></div>\n      <div class=\"simple-circle__circle8\"></div>\n      <div class=\"simple-circle__circle9\"></div>\n      <div class=\"simple-circle__circle10\"></div>\n      <div class=\"simple-circle__circle11\"></div>\n      <div class=\"simple-circle__circle12\"></div>\n    </div>\n    <div class=\"folding-square\" *ngIf=\"name === 'foldingSquare'\">\n      <div class=\"folding-square__square1\"></div>\n      <div class=\"folding-square__square2\"></div>\n      <div class=\"folding-square__square4\"></div>\n      <div class=\"folding-square__square3\"></div>\n    </div>\n  </ng-template>\n</ng-container>",
                styles: ["ion-content{--background:var(--content-background,rgba(0,0,0,0.15));height:100%;left:0;top:0;width:100%;z-index:var(--content-z-index,10000)}@-webkit-keyframes rotate-square{0%{-webkit-transform:perspective(120px)}50%{-webkit-transform:perspective(120px) rotateY(180deg)}to{-webkit-transform:perspective(120px) rotateY(180deg) rotateX(180deg)}}@keyframes rotate-square{0%{-webkit-transform:perspective(120px) rotateX(0deg) rotateY(0deg);transform:perspective(120px) rotateX(0deg) rotateY(0deg)}50%{-webkit-transform:perspective(120px) rotateX(-180.1deg) rotateY(0deg);transform:perspective(120px) rotateX(-180.1deg) rotateY(0deg)}to{-webkit-transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg);transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg)}}.rotating-square{-webkit-animation:rotate-square 1.2s ease-in-out infinite;animation:rotate-square 1.2s ease-in-out infinite;background-color:var(--color,#333);height:var(--size,40px);width:var(--size,40px)}@-webkit-keyframes chase{to{-webkit-transform:rotate(1turn)}}@keyframes chase{to{transform:rotate(1turn)}}@-webkit-keyframes chase-dot{80%,to{-webkit-transform:rotate(1turn)}}@keyframes chase-dot{80%,to{transform:rotate(1turn)}}@-webkit-keyframes chase-dot-before{50%{-webkit-transform:scale(.4)}0%,to{-webkit-transform:scale(1)}}@keyframes chase-dot-before{50%{transform:scale(.4)}0%,to{transform:scale(1)}}.chasing-dot{-webkit-animation:chase 2.5s linear infinite both;animation:chase 2.5s linear infinite both;height:var(--size,40px);margin:20px;position:relative;width:var(--size,40px)}.chasing-dot__dot{-webkit-animation:chase-dot 2s ease-in-out infinite both!important;animation:chase-dot 2s ease-in-out infinite both!important;height:100%;left:0;position:absolute;top:0;width:100%}.chasing-dot__dot:first-child{-webkit-animation-delay:-1.1s!important;animation-delay:-1.1s!important}.chasing-dot__dot:nth-child(2){-webkit-animation-delay:-1s!important;animation-delay:-1s!important}.chasing-dot__dot:nth-child(3){-webkit-animation-delay:-.9s!important;animation-delay:-.9s!important}.chasing-dot__dot:nth-child(4){-webkit-animation-delay:-.8s!important;animation-delay:-.8s!important}.chasing-dot__dot:nth-child(5){-webkit-animation-delay:-.7s!important;animation-delay:-.7s!important}.chasing-dot__dot:nth-child(6){-webkit-animation-delay:-.6s!important;animation-delay:-.6s!important}.chasing-dot__dot:before{-webkit-animation:chase-dot-before 2s ease-in-out infinite both!important;animation:chase-dot-before 2s ease-in-out infinite both!important;background-color:var(--color,#000);border-radius:100%;content:\"\";display:block;height:var(--element-size,10px);width:var(--element-size,10px)}.chasing-dot__dot:before:first-child{-webkit-animation-delay:-1.1s!important;animation-delay:-1.1s!important}.chasing-dot__dot:before:nth-child(2){-webkit-animation-delay:-1s!important;animation-delay:-1s!important}.chasing-dot__dot:before:nth-child(3){-webkit-animation-delay:-.9s!important;animation-delay:-.9s!important}.chasing-dot__dot:before:nth-child(4){-webkit-animation-delay:-.8s!important;animation-delay:-.8s!important}.chasing-dot__dot:before:nth-child(5){-webkit-animation-delay:-.7s!important;animation-delay:-.7s!important}.chasing-dot__dot:before:nth-child(6){-webkit-animation-delay:-.6s!important;animation-delay:-.6s!important}@-webkit-keyframes bounce{0%,to{-webkit-transform:scale(0)}50%{-webkit-transform:scale(1)}}@keyframes bounce{0%,to{transform:scale(0)}50%{transform:scale(1)}}.double-bouncing-dot{height:var(--size,40px);position:relative;width:var(--size,40px)}.double-bouncing-dot__dot1,.double-bouncing-dot__dot2{-webkit-animation:bounce 2s ease-in-out infinite;animation:bounce 2s ease-in-out infinite;background-color:var(--color,#333);border-radius:50%;height:100%;left:0;opacity:.6;position:absolute;top:0;width:100%}.double-bouncing-dot__dot2{-webkit-animation-delay:-1s;animation-delay:-1s}@-webkit-keyframes stretch-deltay{0%,40%,to{-webkit-transform:scaleY(.4)}20%{-webkit-transform:scaleY(1)}}@keyframes stretch-deltay{0%,40%,to{-webkit-transform:scaleY(.4);transform:scaleY(.4)}20%{-webkit-transform:scaleY(1);transform:scaleY(1)}}.stretching-bars{height:var(--size,40px);text-align:center;width:var(--size,40px)}.stretching-bars>div{-webkit-animation:stretch-deltay 1.2s ease-in-out infinite;animation:stretch-deltay 1.2s ease-in-out infinite;background-color:var(--color,#333);display:inline-block;height:100%;margin-right:var(--element-margin,1px);width:var(--element-size,6px)}.stretching-bars__rect2{-webkit-animation-delay:-1.1s!important;animation-delay:-1.1s!important}.stretching-bars__rect3{-webkit-animation-delay:-1s!important;animation-delay:-1s!important}.stretching-bars__rect4{-webkit-animation-delay:-.9s!important;animation-delay:-.9s!important}.stretching-bars__rect5{-webkit-animation-delay:-.8s!important;animation-delay:-.8s!important}@-webkit-keyframes square-chase{25%{-webkit-transform:translateX(42px) rotate(-90deg) scale(.5)}50%{-webkit-transform:translateX(42px) translateY(42px) rotate(-180deg)}75%{-webkit-transform:translateX(0) translateY(42px) rotate(-270deg) scale(.5)}to{-webkit-transform:rotate(-1turn)}}@keyframes square-chase{25%{transform:translateX(42px) rotate(-90deg) scale(.5)}50%{transform:translateX(42px) translateY(42px) rotate(-179deg)}50.1%{transform:translateX(42px) translateY(42px) rotate(-180deg)}75%{transform:translateX(0) translateY(42px) rotate(-270deg) scale(.5)}to{transform:rotate(-1turn)}}.chasing-squares{height:var(--size,40px);position:relative;width:var(--size,40px)}.chasing-squares__square1,.chasing-squares__square2{-webkit-animation:square-chase 1.8s ease-in-out infinite;animation:square-chase 1.8s ease-in-out infinite;background-color:var(--color,#333);height:var(--element-size,15px);left:0;position:absolute;top:0;width:var(--element-size,15px)}.chasing-squares__square2{-webkit-animation-delay:-.9s;animation-delay:-.9s}@-webkit-keyframes scaleout{0%{-webkit-transform:scale(0)}to{-webkit-transform:scale(1);opacity:0}}@keyframes scaleout{0%{transform:scale(0)}to{opacity:0;transform:scale(1)}}.scaling-dot{-webkit-animation:scaleout 1s ease-in-out infinite;animation:scaleout 1s ease-in-out infinite;background-color:var(--color,#333);border-radius:100%;height:var(--size,40px);width:var(--size,40px)}@-webkit-keyframes rotate{to{-webkit-transform:rotate(1turn)}}@keyframes rotate{to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}.double-rotating-dot{-webkit-animation:rotate 2s linear infinite;animation:rotate 2s linear infinite;height:var(--size,40px);position:relative;text-align:center;width:var(--size,40px)}.double-rotating-dot__dot1,.double-rotating-dot__dot2{-webkit-animation:bounce 2s ease-in-out infinite;animation:bounce 2s ease-in-out infinite;background-color:var(--color,#333);border-radius:100%;display:inline-block;height:var(--element-size,60%);position:absolute;top:0;width:var(--element-size,60%)}.double-rotating-dot__dot2{-webkit-animation-delay:-1s;animation-delay:-1s;bottom:0;top:auto}@-webkit-keyframes bouncedelay{0%,80%,to{-webkit-transform:scale(0)}40%{-webkit-transform:scale(1)}}@keyframes bouncedelay{0%,80%,to{transform:scale(0)}40%{transform:scale(1)}}.three-bouncing-dot{text-align:center;width:var(--size,70px)}.three-bouncing-dot>div{-webkit-animation:bouncedelay 1.4s ease-in-out infinite both;animation:bouncedelay 1.4s ease-in-out infinite both;background-color:var(--color,#333);border-radius:100%;display:inline-block;height:var(--element-size,18px);margin-right:var(--element-margin,5px);width:var(--element-size,18px)}.three-bouncing-dot__dot1{-webkit-animation-delay:-.32s!important;animation-delay:-.32s!important}.three-bouncing-dot__dot2{-webkit-animation-delay:-.16s!important;animation-delay:-.16s!important}@-webkit-keyframes circle-bounce{0%,80%,to{transform:scale(0)}40%{transform:scale(1)}}@keyframes circle-bounce{0%,80%,to{transform:scale(0)}40%{transform:scale(1)}}.rotating-dot-circle{height:var(--size,40px);position:relative;width:var(--size,40px)}.rotating-dot-circle>div{height:100%;left:0;position:absolute;top:0;width:100%}.rotating-dot-circle>div:before{-webkit-animation:circle-bounce 1.2s ease-in-out infinite both;animation:circle-bounce 1.2s ease-in-out infinite both;background-color:var(--color,#333);border-radius:100%;content:\"\";display:block;height:var(--element-size,15%);margin:0 auto;width:var(--element-size,15%)}.rotating-dot-circle__dot2{transform:rotate(30deg)}.rotating-dot-circle__dot2:before{-webkit-animation-delay:-1.1s!important;animation-delay:-1.1s!important}.rotating-dot-circle__dot3{transform:rotate(60deg)}.rotating-dot-circle__dot3:before{-webkit-animation-delay:-1s!important;animation-delay:-1s!important}.rotating-dot-circle__dot4{transform:rotate(90deg)}.rotating-dot-circle__dot4:before{-webkit-animation-delay:-.9s!important;animation-delay:-.9s!important}.rotating-dot-circle__dot5{transform:rotate(120deg)}.rotating-dot-circle__dot5:before{-webkit-animation-delay:-.8s!important;animation-delay:-.8s!important}.rotating-dot-circle__dot6{transform:rotate(150deg)}.rotating-dot-circle__dot6:before{-webkit-animation-delay:-.7s!important;animation-delay:-.7s!important}.rotating-dot-circle__dot7{transform:rotate(180deg)}.rotating-dot-circle__dot7:before{-webkit-animation-delay:-.6s!important;animation-delay:-.6s!important}.rotating-dot-circle__dot8{transform:rotate(210deg)}.rotating-dot-circle__dot8:before{-webkit-animation-delay:-.5s!important;animation-delay:-.5s!important}.rotating-dot-circle__dot9{transform:rotate(240deg)}.rotating-dot-circle__dot9:before{-webkit-animation-delay:-.4s!important;animation-delay:-.4s!important}.rotating-dot-circle__dot10{transform:rotate(270deg)}.rotating-dot-circle__dot10:before{-webkit-animation-delay:-.3s!important;animation-delay:-.3s!important}.rotating-dot-circle__dot11{transform:rotate(300deg)}.rotating-dot-circle__dot11:before{-webkit-animation-delay:-.2s!important;animation-delay:-.2s!important}.rotating-dot-circle__dot12{transform:rotate(330deg)}.rotating-dot-circle__dot12:before{-webkit-animation-delay:-.1s!important;animation-delay:-.1s!important}@-webkit-keyframes square-scale{0%,70%,to{transform:scaleX(1)}35%{transform:scale3D(0,0,1)}}@keyframes square-scale{0%,70%,to{transform:scaleX(1)}35%{transform:scale3D(0,0,1)}}.fading-square{height:var(--size,40px);width:var(--size,40px)}.fading-square>div{-webkit-animation:square-scale 1.3s ease-in-out infinite;animation:square-scale 1.3s ease-in-out infinite;background-color:var(--color,#333);float:left;height:var(--element-size,33%);width:var(--element-size,33%)}.fading-square__square1{-webkit-animation-delay:.2s!important;animation-delay:.2s!important}.fading-square__square2{-webkit-animation-delay:.3s!important;animation-delay:.3s!important}.fading-square__square3{-webkit-animation-delay:.4s!important;animation-delay:.4s!important}.fading-square__square4{-webkit-animation-delay:.1s!important;animation-delay:.1s!important}.fading-square__square5{-webkit-animation-delay:.2s!important;animation-delay:.2s!important}.fading-square__square6{-webkit-animation-delay:.3s!important;animation-delay:.3s!important}.fading-square__square7{-webkit-animation-delay:0s!important;animation-delay:0s!important}.fading-square__square8{-webkit-animation-delay:.1s!important;animation-delay:.1s!important}.fading-square__square9{-webkit-animation-delay:.2s!important;animation-delay:.2s!important}@-webkit-keyframes spinner-rotation{0%,39%,to{opacity:0}40%{opacity:1}}@keyframes spinner-rotation{0%,39%,to{opacity:0}40%{opacity:1}}.simple-circle{height:var(--size,40px);position:relative;width:var(--size,40px)}.simple-circle>div{height:100%;left:0;position:absolute;top:0;width:100%}.simple-circle>div:before{-webkit-animation:spinner-rotation 1.2s ease-in-out infinite both;animation:spinner-rotation 1.2s ease-in-out infinite both;background-color:var(--color,#333);border-radius:100%;content:\"\";display:block;height:var(--element-size,15%);margin:0 auto;width:var(--element-size,15%)}.simple-circle__circle2{transform:rotate(30deg)}.simple-circle__circle2:before{-webkit-animation-delay:-1.1s!important;animation-delay:-1.1s}.simple-circle__circle3{transform:rotate(60deg)}.simple-circle__circle3:before{-webkit-animation-delay:-1s!important;animation-delay:-1s}.simple-circle__circle4{transform:rotate(90deg)}.simple-circle__circle4:before{-webkit-animation-delay:-.9s!important;animation-delay:-.9s}.simple-circle__circle5{transform:rotate(120deg)}.simple-circle__circle5:before{-webkit-animation-delay:-.8s!important;animation-delay:-.8s}.simple-circle__circle6{transform:rotate(150deg)}.simple-circle__circle6:before{-webkit-animation-delay:-.7s!important;animation-delay:-.7s}.simple-circle__circle7{transform:rotate(180deg)}.simple-circle__circle7:before{-webkit-animation-delay:-.6s!important;animation-delay:-.6s}.simple-circle__circle8{transform:rotate(210deg)}.simple-circle__circle8:before{-webkit-animation-delay:-.5s!important;animation-delay:-.5s}.simple-circle__circle9{transform:rotate(240deg)}.simple-circle__circle9:before{-webkit-animation-delay:-.4s!important;animation-delay:-.4s}.simple-circle__circle10{transform:rotate(270deg)}.simple-circle__circle10:before{-webkit-animation-delay:-.3s!important;animation-delay:-.3s}.simple-circle__circle11{transform:rotate(300deg)}.simple-circle__circle11:before{-webkit-animation-delay:-.2s!important;animation-delay:-.2s}.simple-circle__circle12{transform:rotate(330deg)}.simple-circle__circle12:before{-webkit-animation-delay:-.1s!important;animation-delay:-.1s}@-webkit-keyframes fold{0%,10%{opacity:0;transform:perspective(140px) rotateX(-180deg)}25%,75%{opacity:1;transform:perspective(140px) rotateX(0deg)}90%,to{opacity:0;transform:perspective(140px) rotateY(180deg)}}@keyframes fold{0%,10%{opacity:0;transform:perspective(140px) rotateX(-180deg)}25%,75%{opacity:1;transform:perspective(140px) rotateX(0deg)}90%,to{opacity:0;transform:perspective(140px) rotateY(180deg)}}.folding-square{height:var(--size,40px);position:relative;transform:rotate(45deg);width:var(--size,40px)}.folding-square>div{float:left;height:50%;position:relative;transform:scale(1.1);width:50%}.folding-square>div:before{-webkit-animation:fold 2.4s linear infinite both;animation:fold 2.4s linear infinite both;background-color:var(--color,#333);content:\"\";height:100%;left:0;position:absolute;top:0;transform-origin:100% 100%;width:100%}.folding-square__square2{transform:scale(1.1) rotate(90deg)!important}.folding-square__square2:before{-webkit-animation-delay:.3s!important;animation-delay:.3s!important}.folding-square__square3{transform:scale(1.1) rotate(180deg)!important}.folding-square__square3:before{-webkit-animation-delay:.6s!important;animation-delay:.6s!important}.folding-square__square4{transform:scale(1.1) rotate(270deg)!important}.folding-square__square4:before{-webkit-animation-delay:.9s!important;animation-delay:.9s!important}"]
            },] }
];
SpinnerComponent.propDecorators = {
    withContainer: [{ type: Input }],
    name: [{ type: Input }]
};

class SpinnerModule {
}
SpinnerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    SpinnerComponent
                ],
                imports: [
                    CommonModule,
                    IonicModule,
                    CentralizerModule
                ],
                exports: [
                    SpinnerComponent
                ]
            },] }
];

class ErrorContainerComponent {
    constructor() {
        this.reload = new EventEmitter();
    }
}
ErrorContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'error-container',
                template: "<div #ref><ng-content></ng-content></div>\n\n<div class=\"error\" *ngIf=\"ref.childNodes.length == 0\">\n  <span class=\"error__message\" [innerHtml]=\"message\"></span>\n  <ion-button class=\"error__button\" [fill]=\"buttonFill\" [shape]=\"buttonShape\" [color]=\"buttonColor\" *ngIf=\"buttonLabel && buttonLabel.length\" (click)=\"reload.emit()\">\n    <span>{{buttonLabel}}</span>\n  </ion-button>\n</div>\n",
                styles: [".error{padding:var(--padding-top,0) var(--padding-right,0) var(--padding-bottom,0) var(--padding-left,0);text-align:var(--align,center);width:var(--width,100%)}.error__message{color:var(--message-color,#ddd);display:inline-block;font-size:var(--message-font-size,18px);font-weight:var(--message-font-weight,400);margin-bottom:var(--message-margin-bottom,15px);text-align:var(--message-align,left);width:100%}.error__button{height:var(--button-height)!important;width:var(--button-width)!important}"]
            },] }
];
ErrorContainerComponent.propDecorators = {
    message: [{ type: Input }],
    buttonLabel: [{ type: Input, args: ['retryButtonLabel',] }],
    buttonFill: [{ type: Input, args: ['retryButtonFill',] }],
    buttonShape: [{ type: Input, args: ['retryButtonShape',] }],
    buttonColor: [{ type: Input, args: ['retryButtonColor',] }],
    reload: [{ type: Output }]
};

class ErrorContainerModule {
}
ErrorContainerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ErrorContainerComponent
                ],
                imports: [
                    CommonModule,
                    IonicModule,
                ],
                exports: [
                    ErrorContainerComponent
                ]
            },] }
];

class WsDataComponent {
    constructor() {
        this.retry = new EventEmitter();
    }
}
WsDataComponent.decorators = [
    { type: Component, args: [{
                selector: 'ws-data',
                template: "<spinner class=\"spinner\" *ngIf=\"options.loading$ | async; else callEndend\" [withContainer]=\"options.loadingSpinnerWithContainer\" [name]=\"options.loadingSpinnerName\">\n  <ng-content select=[customSpinner]></ng-content>\n</spinner>\n<ng-template #callEndend>\n  <error-container class=\"error-container\" *ngIf=\"options.error$ | async\"\n    [message]=\"options.errorMessage\" [retryButtonLabel]=\"options.errorRetryButtonLabel\"\n    [retryButtonFill]=\"options.errorRetryButtonFill\" [retryButtonShape]=\"options.errorRetryButtonShape\"\n    [retryButtonColor]=\"options.errorRetryButtonColor\" (reload)=\"retry.emit()\">\n    <ng-content select=[customError]></ng-content>\n  </error-container>\n\n  <ng-content select=[dataContent]></ng-content>\n</ng-template>",
                styles: [".spinner{--color:var(--spinner-color);--content-background:var(--spinner-content-background,transparent);--content-z-index:var(--spinner-content-z-index,rgba(0,0,0,0.15));--element-margin:var(--spinner-element-margin);--element-size:var(--spinner-element-size);--size:var(--spinner-size)}.error-container{--align:var(--error-container-align);--button-height:var(--error-container-button-height);--button-width:var(--error-container-button-width);--message-align:var(--error-container-message-align);--message-color:var(--error-container-message-color);--message-font-size:var(--error-container-message-font-size);--message-font-weight:var(--error-container-message-font-weight);--message-margin-bottom:var(--error-container-message-margin-bottom);--padding-bottom:var(--error-container-padding-bottom);--padding-left:var(--error-container-padding-left);--padding-right:var(--error-container-padding-right);--padding-top:var(--error-container-padding-top);--width:var(--error-container-width)}"]
            },] }
];
WsDataComponent.propDecorators = {
    options: [{ type: Input }],
    retry: [{ type: Output }]
};

class WsDataModule {
}
WsDataModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    WsDataComponent
                ],
                imports: [
                    CommonModule,
                    IonicModule,
                    SpinnerModule,
                    ErrorContainerModule
                ],
                exports: [
                    WsDataComponent
                ]
            },] }
];

class WsDataListComponent {
    constructor() {
        this.retry = new EventEmitter();
    }
    ngOnInit() {
        this.dataAvailableCondition$ = (typeof this.options.dataAvailableCondition === 'boolean') ? of(this.options.dataAvailableCondition) : this.options.dataAvailableCondition;
    }
}
WsDataListComponent.decorators = [
    { type: Component, args: [{
                selector: 'ws-data-list',
                template: "<spinner class=\"spinner\" *ngIf=\"options.loading$ | async; else callEndend\" [withContainer]=\"options.loadingSpinnerWithContainer\" [name]=\"options.loadingSpinnerName\">\n  <ng-content select=[customSpinner]></ng-content>\n</spinner>\n<ng-template #callEndend>\n  <error-container class=\"error-container\" *ngIf=\"options.error$ | async\"\n    [message]=\"options.errorMessage\" [retryButtonLabel]=\"options.errorRetryButtonLabel\"\n    [retryButtonFill]=\"options.errorRetryButtonFill\" [retryButtonShape]=\"options.errorRetryButtonShape\"\n    [retryButtonColor]=\"options.errorRetryButtonColor\" (reload)=\"retry.emit()\">\n    <ng-content select=[customError]></ng-content>\n  </error-container>\n\n  <ng-container *ngIf=\"dataAvailableCondition$ | async\">\n    <ng-container *ngIf=\"(options.data$ | async) as items\">\n      <error-container [message]=\"options.emptyListMessage\" *ngIf=\"!items.length\">\n        <ng-content select=[customEmptyListError]></ng-content>\n      </error-container>\n  \n      <ng-container *ngFor=\"let item of items\">\n        <ng-container *ngTemplateOutlet=\"options.dataItemTemplate; context: {$implicit: item}\"></ng-container>\n      </ng-container>\n    </ng-container>\n  </ng-container>\n</ng-template>",
                styles: [".spinner{--color:var(--spinner-color);--content-background:var(--spinner-content-background,transparent);--content-z-index:var(--spinner-content-z-index,rgba(0,0,0,0.15));--element-margin:var(--spinner-element-margin);--element-size:var(--spinner-element-size);--size:var(--spinner-size)}.error-container{--align:var(--error-container-align);--button-height:var(--error-container-button-height);--button-width:var(--error-container-button-width);--message-align:var(--error-container-message-align);--message-color:var(--error-container-message-color);--message-font-size:var(--error-container-message-font-size);--message-font-weight:var(--error-container-message-font-weight);--message-margin-bottom:var(--error-container-message-margin-bottom);--padding-bottom:var(--error-container-padding-bottom);--padding-left:var(--error-container-padding-left);--padding-right:var(--error-container-padding-right);--padding-top:var(--error-container-padding-top);--width:var(--error-container-width)}"]
            },] }
];
WsDataListComponent.propDecorators = {
    options: [{ type: Input }],
    retry: [{ type: Output }]
};

class WsDataListModule {
}
WsDataListModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    WsDataListComponent
                ],
                imports: [
                    CommonModule,
                    IonicModule,
                    SpinnerModule,
                    ErrorContainerModule
                ],
                exports: [
                    WsDataListComponent
                ]
            },] }
];

;

const LibConfigService = new InjectionToken('LibConfig');
class IonicAngularUtilitiesModule {
    static forRoot(config) {
        return {
            ngModule: IonicAngularUtilitiesModule,
            providers: [
                //Here provide services
                {
                    provide: LibConfigService,
                    useValue: config
                }
            ]
        };
    }
}
IonicAngularUtilitiesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [
                    CommonModule,
                    IonicModule
                ],
                exports: []
            },] }
];

////////////////////Mock providers
class Mock {
    constructor(config) {
        this.config = config;
    }
    isMockAvailable(mock) {
        return this.config && this.config.ionicMock && this.config.ionicMock[mock];
    }
}
Mock.decorators = [
    { type: Injectable }
];
Mock.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [LibConfigService,] }] }
];
class AppVersionMock extends Mock {
    getAppName() {
        return new Promise((resolve, reject) => {
            if (this.isMockAvailable('appVersion'))
                this.config.ionicMock.appVersion.appName ?
                    resolve(this.config.ionicMock.appVersion.appName) :
                    reject('An error occured retrieving appName data from AppVersion mock');
        });
    }
    getPackageName() {
        return new Promise((resolve, reject) => {
            if (this.isMockAvailable('appVersion'))
                this.config.ionicMock.appVersion.packageName ?
                    resolve(this.config.ionicMock.appVersion.packageName) :
                    reject('An error occured retrieving packageName data from AppVersion mock');
        });
    }
    getVersionCode() {
        return new Promise((resolve, reject) => {
            if (this.isMockAvailable('appVersion'))
                this.config.ionicMock.appVersion.versionCode ?
                    resolve(this.config.ionicMock.appVersion.versionCode) :
                    reject('An error occured retrieving versionCode data from AppVersion mock');
        });
    }
    getVersionNumber() {
        return new Promise((resolve, reject) => {
            if (this.isMockAvailable('appVersion'))
                this.config.ionicMock.appVersion.versionNumber ?
                    resolve(this.config.ionicMock.appVersion.versionNumber) :
                    reject('An error occured retrieving versionNumber data from AppVersion mock');
        });
    }
}
AppVersionMock.decorators = [
    { type: Injectable }
];
class DeviceMock extends Mock {
    constructor() {
        super(...arguments);
        this.cordova = this.isMockAvailable('device') && this.config.ionicMock.device.cordova ? this.config.ionicMock.device.cordova : "browser";
        this.model = this.isMockAvailable('device') && this.config.ionicMock.device.cordova ? this.config.ionicMock.device.model : "not available";
        this.platform = this.isMockAvailable('device') && this.config.ionicMock.device.cordova ? this.config.ionicMock.device.platform : "not available";
        this.uuid = this.isMockAvailable('device') && this.config.ionicMock.device.cordova ? this.config.ionicMock.device.uuid : "not available";
        this.version = this.isMockAvailable('device') && this.config.ionicMock.device.cordova ? this.config.ionicMock.device.version : "not available";
        this.manufacturer = this.isMockAvailable('device') && this.config.ionicMock.device.cordova ? this.config.ionicMock.device.manufacturer : "not available";
        this.isVirtual = this.isMockAvailable('device') && this.config.ionicMock.device.cordova ? this.config.ionicMock.device.isVirtual : true;
        this.serial = this.isMockAvailable('device') && this.config.ionicMock.device.cordova ? this.config.ionicMock.device.serial : "not available";
    }
}
DeviceMock.decorators = [
    { type: Injectable }
];
class MediaMock {
}
MediaMock.decorators = [
    { type: Injectable }
];
class NativeStorageMock {
    setItem(reference, value) {
        localStorage.setItem(reference, value);
        return new Promise((resolve, reject) => {
            resolve({});
        });
    }
    getItem(reference) {
        let value = localStorage.getItem(reference);
        return new Promise((resolve, reject) => {
            resolve(value);
        });
    }
    remove(reference) {
        localStorage.removeItem(reference);
        return new Promise((resolve, reject) => {
            resolve({});
        });
    }
}
NativeStorageMock.decorators = [
    { type: Injectable }
];
class HTTPMock {
    constructor(http) {
        this.http = http;
    }
    get(endpoint, params, header) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            try {
                let response = yield this.http.get(endpoint, { headers: header }).toPromise();
                resolve({ data: JSON.stringify(response) });
            }
            catch (err) {
                reject(err);
            }
        }));
    }
    post(endpoint, body, header) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            try {
                let response = yield this.http.post(endpoint, body, { headers: header }).toPromise();
                resolve({ data: JSON.stringify(response) });
            }
            catch (err) {
                reject(err);
            }
        }));
    }
    setDataSerializer() {
    }
    setRequestTimeout(timeout) {
        return;
    }
}
HTTPMock.decorators = [
    { type: Injectable }
];
HTTPMock.ctorParameters = () => [
    { type: HttpClient }
];
class StatusBarMock {
    hide() {
    }
}
StatusBarMock.decorators = [
    { type: Injectable }
];
class NavigationBarMock {
    setUp(autohide) {
        return new Promise((resolve, reject) => {
            resolve({});
        });
    }
    hideNavigationBar() {
        return new Promise((resolve, reject) => {
            resolve({});
        });
    }
}
NavigationBarMock.decorators = [
    { type: Injectable }
];
class AndroidFullScreenMock {
    isImmersiveModeSupported() {
        return new Promise((resolve, rejcet) => {
            resolve();
        });
    }
    immersiveMode() {
        return new Promise((resolve, rejcet) => {
            resolve();
        });
    }
    leanMode() {
        return new Promise((resolve, rejcet) => {
            resolve();
        });
    }
}
AndroidFullScreenMock.decorators = [
    { type: Injectable }
];
class NativeAudioMock {
    preloadSimple(id, path) {
        return new Promise((resolve, reject) => {
            resolve();
        });
    }
    preloadComplex(id, path, volume, voices, delay) {
        return new Promise((resolve, reject) => {
            resolve();
        });
    }
    play(id, callback) {
        return new Promise((resolve, reject) => {
            resolve();
        });
    }
    loop(id) {
        return new Promise((resolve, reject) => {
            resolve();
        });
    }
    stop(id) {
        return new Promise((resolve, reject) => {
            resolve();
        });
    }
}
NativeAudioMock.decorators = [
    { type: Injectable }
];
class AdmobMock {
    setOptions(option) {
        return new Promise((resolve, reject) => {
            resolve();
        });
    }
}
AdmobMock.decorators = [
    { type: Injectable }
];
class DeeplinksMock {
    route(paths) {
        return new Observable();
    }
}
DeeplinksMock.decorators = [
    { type: Injectable }
];
/////////////////////Cordova verify function
function hasCordova() {
    return window.hasOwnProperty('cordova');
}
/////////////////////Providers getters
function getAppVersion() {
    return hasCordova() ? AppVersion : AppVersionMock;
}
function getDevice() {
    return hasCordova() ? Device : DeviceMock;
}
function getNativeStorage() {
    return hasCordova() ? NativeStorage : NativeStorageMock;
}
function getHTTP() {
    return hasCordova() ? HTTP : HTTPMock;
}
function getMedia() {
    return hasCordova() ? Media : MediaMock;
}
function getStatusBar() {
    return hasCordova() ? StatusBar : StatusBarMock;
}
function getNavigationBar() {
    return hasCordova() ? NavigationBar : NavigationBarMock;
}
function getAndroidFullScreen() {
    return hasCordova() ? AndroidFullScreen : AndroidFullScreenMock;
}
function getNativeAudio() {
    return hasCordova() ? NativeAudio : NativeAudioMock;
}
function getAdmob() {
    return hasCordova() ? Admob : AdmobMock;
}
function getDeeplinks() {
    return hasCordova() ? Deeplinks : DeeplinksMock;
}

///////////// Components

/**
 * Generated bundle index. Do not edit.
 */

export { AdmobMock, AndroidFullScreenMock, AppVersionMock, CentralizerComponent, CentralizerModule, DebounceButtonComponent, DebounceButtonModule, DebounceClickDirective, DeeplinksMock, DeviceMock, ErrorContainerComponent, ErrorContainerModule, HTTPMock, IonicAngularUtilitiesModule, LibConfigService, MediaMock, NativeAudioMock, NativeStorageMock, NavigationBarMock, SpinnerComponent, SpinnerModule, StatusBarMock, WsDataComponent, WsDataListComponent, WsDataListModule, WsDataModule, getAdmob, getAndroidFullScreen, getAppVersion, getDeeplinks, getDevice, getHTTP, getMedia, getNativeAudio, getNativeStorage, getNavigationBar, getStatusBar, hasCordova };
//# sourceMappingURL=ionic-angular-utilities.js.map
